package tech.nevets.quickflags;

import org.junit.jupiter.api.Test;
import tech.nevets.quickflags.testflags.HelpFlag;

import org.junit.jupiter.api.Assertions;

public class FlagMappingTest {

    @Test
    public void testShortFlags() {
        String[] args = new String[]{"-h", "someArg", "-d", "Another Thing"};
        FlagHandler fh = new FlagHandler()
                .registerFlag(new HelpFlag())
                .registerFlag(FlagFactory.createFlag("dino"));
        fh.loadArgs(args);

        String helpVal = fh.getValue("help");
        String dinoVal = fh.getValue("dino");

        Assertions.assertEquals("someArg", helpVal);
        Assertions.assertEquals("Another Thing", dinoVal);
    }

    @Test
    public void getRemainingArgs() {
        String[] args = new String[]{"-h", "someArg", "-d", "Another Thing", "regularArg", "andSomeMore", "oneLastThing"};
        FlagHandler fh = new FlagHandler()
                .registerFlag(new HelpFlag())
                .registerFlag(FlagFactory.createFlag("dino"));
        fh.loadArgs(args);

        String[] remainingArgs = fh.getRemainingArgs();

        Assertions.assertEquals(3, remainingArgs.length);
    }

    @Test
    public void getRemainingArgsEdgeCase() {
        String[] args = new String[]{"regularArg"};
        FlagHandler fh = new FlagHandler()
                .registerFlag(new HelpFlag())
                .registerFlag(FlagFactory.createFlag("dino"));
        fh.loadArgs(args);

        String[] remainingArgs = fh.getRemainingArgs();

        Assertions.assertEquals("regularArg", remainingArgs[0]);
    }
}
